@@ -657,7 +657,7 @@ class Book:
 
         # Id per group...
         text["id"] = text.groupby(
-            ["line_num", "page", "side"]).ngroup() # "block_num", "par_num"
+            ["line_num", "page", "side", "block_num", "par_num"]).ngroup()
 
         # Create groups/lines...
         text["keep"] = 0
@@ -678,15 +678,24 @@ class Book:
         text = text.reset_index(drop=True)
 
         # Create lines bases on commas and '-'
+        # change other strange symbols/characters
+        text["text"] = text["text"].str.replace(r",,", ".,", regex=True)
+        text["text"] = text["text"].str.replace(r"-—", "— ", regex=True)
+        text["text"] = text["text"].str.replace(r"-", "— ", regex=True)
+        text["text"] = text["text"].str.replace(r"—", "— ", regex=True)
+        text["text"] = text["text"].str.replace(r"\.—", "—", regex=True)
+        text["text"] = text["text"].str.replace(r"—[ ]{0,1}—", "—", regex=True)
+        text["text"] = text["text"].str.replace(r"— ,", "—", regex=True)
+        text["text"] = text["text"].str.replace(r", —", "—", regex=True)
+
         length = text.shape[0]
         text["end"] = text["text"].astype(str).str[-1]
-        text["beginning"] = text["text"].astype(str).str[-1]
 
         for i in range(length-1, -1, -1):
             try:
                 if (text.at[i, "end"] == "," or text.at[i, "end"] == "-" or text.at[i, "end"] == "—" or re.search("^—[ ]{0,1}[0-9]{3,}$", text.at[i+1, "text"])) and text.at[i, "page"] == text.at[i+1, "page"]:
-                    text.at[i, "text"] = text.at[i, "text"] + " " + text.at[i + 1, "text"]
-                    text.at[i + 1, "text"] = ""
+                    text.at[i, "text"] = text.at[i, "text"] + " " + text.at[i+1, "text"]
+                    text.at[i+1, "text"] = ""
             except:
                 pass
 
@@ -1007,7 +1016,7 @@ class Book:
 
         csv = df
 
-        extract = csv['text'].str.extract(r"(^.*), ([0-9]{0,})[—\- ]{1,3}([0-9]{1,})$")
+        extract = csv['text'].str.extract(r"(^.*?[^0-9])([0-9]*)[—\- ]{1,3}([0-9]{1,})$")
         extract = extract.join(csv, how='outer')
 
         del csv
